@@ -7,7 +7,8 @@ class Auth(APIBase):
     def login(self, username: str, password: str) -> Response:
         data = {"username": username, "password": password}
 
-        return self.client.post(url="/v1/login/", json=data)
+        with self.get_client() as client:
+            return client.post(url="/v1/login/", json=data)
 
     def password_change(
         self, old_password: str, new_password: str, reset_tokens: bool = False
@@ -19,14 +20,16 @@ class Auth(APIBase):
             "reset_tokens": reset_tokens,
         }
 
-        return self.client.post(url="/v1/auth/password/change/", json=data)
+        with self.get_client() as client:
+            return client.post(url="/v1/auth/password/change/", json=data)
 
 
 class AuthAsync(APIBaseAsync):
     async def login(self, username: str, password: str) -> Response:
         data = {"username": username, "password": password}
 
-        return await self.client.post(url="/v1/login/", json=data)
+        async with self.get_client() as client:
+            return await client.post(url="/v1/login/", json=data)
 
     async def password_change(
         self, old_password: str, new_password: str, reset_tokens: bool = False
@@ -38,6 +41,7 @@ class AuthAsync(APIBaseAsync):
             "reset_tokens": reset_tokens,
         }
 
-        return await self.client.post(
-            url="/v1/auth/password/change/", json=data
-        )
+        async with self.get_client() as client:
+            return await client.post(
+                url="/v1/auth/password/change/", json=data
+            )
